@@ -2,7 +2,7 @@
 errors and exceptions
 """
 
-from werkzeug.exceptions import abort
+from werkzeug.exceptions import HTTPException
 
 
 class ConfigurationError(Exception):
@@ -12,10 +12,12 @@ class ConfigurationError(Exception):
     """
     pass
 
-class RateLimitExceeded(Exception):
+class RateLimitExceeded(HTTPException):
     """
     exception raised when a rate limit is hit.
     The exception results in ``abort(409)`` being called.
     """
+    code = 429
     def __init__(self, limit):
-        abort(429, str(limit))
+        self.description = str(limit)
+        super(RateLimitExceeded, self).__init__()
